@@ -44,16 +44,19 @@ class StrawberryArgumentAnnotation:
     description: Optional[str]
     name: Optional[str]
     deprecation_reason: Optional[str]
+    directives: Iterable[object]
 
     def __init__(
         self,
         description: Optional[str] = None,
         name: Optional[str] = None,
         deprecation_reason: Optional[str] = None,
+        directives: Iterable[object] = (),
     ):
         self.description = description
         self.name = name
         self.deprecation_reason = deprecation_reason
+        self.directives = directives
 
 
 class StrawberryArgument:
@@ -66,6 +69,7 @@ class StrawberryArgument:
         description: Optional[str] = None,
         default: object = _deprecated_UNSET,
         deprecation_reason: Optional[str] = None,
+        directives: Iterable[object] = (),
     ) -> None:
         self.python_name = python_name
         self.graphql_name = graphql_name
@@ -74,6 +78,7 @@ class StrawberryArgument:
         self._type: Optional[StrawberryType] = None
         self.type_annotation = type_annotation
         self.deprecation_reason = deprecation_reason
+        self.directives = directives
 
         # TODO: Consider moving this logic to a function
         self.default = (
@@ -113,6 +118,7 @@ class StrawberryArgument:
                 self.description = arg.description
                 self.graphql_name = arg.name
                 self.deprecation_reason = arg.deprecation_reason
+                self.directives = arg.directives
 
 
 def convert_argument(
@@ -206,9 +212,13 @@ def argument(
     description: Optional[str] = None,
     name: Optional[str] = None,
     deprecation_reason: Optional[str] = None,
+    directives: Iterable[object] = (),
 ) -> StrawberryArgumentAnnotation:
     return StrawberryArgumentAnnotation(
-        description=description, name=name, deprecation_reason=deprecation_reason
+        description=description,
+        name=name,
+        deprecation_reason=deprecation_reason,
+        directives=directives,
     )
 
 
